#  Component	: tecad_snmp.cds
#
#  Description	: Default set of class definition statements for the
#		  SNMP Trap TEC Adapter.
#
#  Primary Author : Francois Schumacker
#
#  Peer Reviewer  :
#
#  (C) COPYRIGHT BIM, sa/nv 1994
#  Unpublished Work
#  All Rights Reserved
#  Licensed Material - BIM, sa/nv.
#

#############################################################################
#  DEFAULT SLOT VALUES
#############################################################################
# The forwarding_agent attribute is commented out so people who upgrade     #
# to TEC 3.7 won't get PARSING FAILED when the event with the new slot      #
# arrives at the TEC server.                                                #
#############################################################################


MAP_DEFAULT
   source = SNMP;
   sub_source = NET;
#  forwarding_agent = $SOURCE_ADDR;
   origin = $AGENT_ADDR;
   adapter_host = $ADAPTER_HOST;

END

#############################################################################
#  CABLETRON-SPECIFIC SNMP TRAPS
#############################################################################

CLASS Port_Segmenting_CBT
  SELECT
    1: ATTR(=,$ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.52");
    2: $SPECIFIC = 257;
    3: ATTR(=,"boardIndex");
    4: ATTR(=,"portIndex");
  FETCH
    1: IPNAME($AGENT_ADDR);
  MAP
    hostname = $F1;
    boardIndex = $V3;
    portIndex = $V4;
    sub_origin = PRINTF("board %s, port %s", $V3, $V4);
END

# CLASS Port_Unsegmenting_CBT
# 'portUnsegementing' traps are mapped to 'portSegmenting' CLOSED
CLASS Port_Segmenting_CBT
  SELECT
    1: ATTR(=,$ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.52");
    2: $SPECIFIC = 258;
    3: ATTR(=,"boardIndex");
    4: ATTR(=,"portIndex");
  FETCH
    1: IPNAME($AGENT_ADDR);
  MAP
    hostname = $F1;
    boardIndex = $V3;
    portIndex = $V4;
    sub_origin = PRINTF("board %s, port %s", $V3, $V4);
    status = CLOSED;
END

CLASS Port_Link_Down_CBT
  SELECT
    1: ATTR(=,$ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.52");
    2: $SPECIFIC = 260;
    3: ATTR(=,"boardIndex");
    4: ATTR(=,"portIndex");
  FETCH
    1: IPNAME($AGENT_ADDR);
  MAP
    hostname = $F1;
    boardIndex = $V3;
    portIndex = $V4;
    sub_origin = PRINTF("board %s, port %s", $V3, $V4);
END

# CLASS Port_Link_Up_CBT
# 'portLinkUp' traps are mapped to 'portLinkDown' CLOSED
CLASS Port_Link_Down_CBT
  SELECT
    1: ATTR(=,$ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.52");
    2: $SPECIFIC = 259;
    3: ATTR(=,"boardIndex");
    4: ATTR(=,"portIndex");
  FETCH
    1: IPNAME($AGENT_ADDR);
  MAP
    hostname = $F1;
    boardIndex = $V3;
    portIndex = $V4;
    sub_origin = PRINTF("board %s, port %s", $V3, $V4);
    status = CLOSED;
END

CLASS Source_Address_New_CBT
  SELECT
    1: ATTR(=,$ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.52");
    2: $SPECIFIC = 261;
    3: ATTR(=,"boardIndex");
    4: ATTR(=,"portIndex");
    5: ATTR(=,"portSourceAddr");
  FETCH
    1: IPNAME($AGENT_ADDR);
  MAP
    hostname = $F1;
    boardIndex = $V3;
    portIndex = $V4;
    portSourceAddr = $V5;
    sub_origin = PRINTF("board %s, port %s", $V3, $V4);
END

CLASS Source_Address_Timeout_CBT
  SELECT
    1: ATTR(=,$ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.52");
    2: $SPECIFIC = 262;
    3: ATTR(=,"boardIndex");
    4: ATTR(=,"portIndex");
    5: ATTR(=,"portSourceAddr");
  FETCH
    1: IPNAME($AGENT_ADDR);
  MAP
    hostname = $F1;
    boardIndex = $V3;
    portIndex = $V4;
    portSourceAddr = $V5;
    sub_origin = PRINTF("board %s, port %s", $V3, $V4);
END

CLASS Board_Removal_CBT
  SELECT
    1: ATTR(=,$ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.52");
    2: $SPECIFIC = 263;
    3: ATTR(=,"boardIndex");
  FETCH
    1: IPNAME($AGENT_ADDR);
  MAP
    hostname = $F1;
    boardIndex = $V3;
    sub_origin = PRINTF("board %s", $V3);
END

CLASS Board_Insertion_CBT
  SELECT
    1: ATTR(=,$ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.52");
    2: $SPECIFIC = 264;
    3: ATTR(=,"boardIndex");
    4: ATTR(=,"boardType");
  FETCH
    1: IPNAME($AGENT_ADDR);
  MAP
    hostname = $F1;
    boardIndex = $V3;
    boardType = $V4;
    sub_origin = PRINTF("board %s", $V3);
END

CLASS Active_Port_In_Redundant_Circuit_Failed_CBT
  SELECT
    1: ATTR(=,$ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.52");
    2: $SPECIFIC = 265;
    3: ATTR(=,"boardIndex");
    4: ATTR(=,"portIndex");
    5: ATTR(=,"portRedundCrt");
  FETCH
    1: IPNAME($AGENT_ADDR);
  MAP
    hostname = $F1;
    boardIndex = $V3;
    portIndex = $V4;
    portRedundCrt = $V5;
    sub_origin = PRINTF("board %s, port %s", $V3, $V4);
END

CLASS Redundant_Port_Activated_CBT
  SELECT
    1: ATTR(=,$ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.52");
    2: $SPECIFIC = 266;
    3: ATTR(=,"boardIndex");
    4: ATTR(=,"portIndex");
    5: ATTR(=,"portRedundCrt");
  FETCH
    1: IPNAME($AGENT_ADDR);
  MAP
    hostname = $F1;
    boardIndex = $V3;
    portIndex = $V4;
    portRedundCrt = $V5;
    sub_origin = PRINTF("board %s, port %s", $V3, $V4);
END

CLASS Redundant_Port_Test_Failed_CBT
  SELECT
    1: ATTR(=,$ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.52");
    2: $SPECIFIC = 267;
    3: ATTR(=,"boardIndex");
    4: ATTR(=,"portIndex");
    5: ATTR(=,"portRedundCrt");
  FETCH
    1: IPNAME($AGENT_ADDR);
  MAP
    hostname = $F1;
    boardIndex = $V3;
    portIndex = $V4;
    portRedundCrt = $V5;
    sub_origin = PRINTF("board %s, port %s", $V3, $V4);
END

CLASS Device_Traffic_Threshold_Exceeded_CBT
  SELECT
    1: ATTR(=,$ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.52");
    2: $SPECIFIC = 268;
    3: ATTR(=,"devTrafficThreshold");
    4: ATTR(=,"deviceTimebase");
  FETCH
    1: IPNAME($AGENT_ADDR);
  MAP
    hostname = $F1;
    devTrafficThreshold = $V3;
    deviceTimebase = $V4;
END

CLASS Device_Error_Threshold_Exceeded_CBT
  SELECT
    1: ATTR(=,$ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.52");
    2: $SPECIFIC = 269;
    3: ATTR(=,"devErrorThreshold");
    4: ATTR(=,"devErrorSource");
    5: ATTR(=,"deviceTimebase");
  FETCH
    1: IPNAME($AGENT_ADDR);
  MAP
    hostname = $F1;
    devErrorThreshold = $V3;
    devErrorSource = $V4;
    deviceTimebase = $V5;
END

CLASS Device_Collision_Threshold_Exceeded_CBT
  SELECT
    1: ATTR(=,$ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.52");
    2: $SPECIFIC = 270;
    3: ATTR(=,"devCollsThreshold");
    4: ATTR(=,"deviceTimebase");
  FETCH
    1: IPNAME($AGENT_ADDR);
  MAP
    hostname = $F1;
    devCollsThreshold = $V3;
    deviceTimebase = $V4;
END

CLASS Board_Traffic_Threshold_Exceeded_CBT
  SELECT
    1: ATTR(=,$ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.52");
    2: $SPECIFIC = 271;
    3: ATTR(=,"bdTrafficThreshold");
    4: ATTR(=,"deviceTimebase");
    5: ATTR(=,"boardIndex");
  FETCH
    1: IPNAME($AGENT_ADDR);
  MAP
    hostname = $F1;
    bdTrafficThreshold = $V3;
    deviceTimebase = $V4;
    boardIndex = $V5;
    sub_origin = PRINTF("board %s", $V5);
END

CLASS Board_Error_Threshold_Exceeded_CBT
  SELECT
    1: ATTR(=,$ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.52");
    2: $SPECIFIC = 272;
    3: ATTR(=,"bdErrorThreshold");
    4: ATTR(=,"bdErrorSource");
    5: ATTR(=,"deviceTimebase");
    6: ATTR(=,"boardIndex");
  FETCH
    1: IPNAME($AGENT_ADDR);
  MAP
    hostname = $F1;
    bdErrorThreshold = $V3;
    bdErrorSource = $V4;
    deviceTimebase = $V5;
    boardIndex = $V6;
    sub_origin = PRINTF("board %s", $V6);
END

CLASS Board_Collision_Threshold_Exceeded_CBT
  SELECT
    1: ATTR(=,$ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.52");
    2: $SPECIFIC = 273;
    3: ATTR(=,"bdCollsThreshold");
    4: ATTR(=,"deviceTimebase");
    5: ATTR(=,"boardIndex");
  FETCH
    1: IPNAME($AGENT_ADDR);
  MAP
    hostname = $F1;
    bdCollsThreshold = $V3;
    deviceTimebase = $V4;
    boardIndex = $V5;
    sub_origin = PRINTF("board %s", $V5);
END

CLASS Port_Traffic_Threshold_Exceeded_CBT
  SELECT
    1: ATTR(=,$ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.52");
    2: $SPECIFIC = 274;
    3: ATTR(=,"portTrafficThreshold");
    4: ATTR(=,"deviceTimebase");
    5: ATTR(=,"boardIndex");
    6: ATTR(=,"portIndex");
  FETCH
    1: IPNAME($AGENT_ADDR);
  MAP
    hostname = $F1;
    portTrafficThreshold = $V3;
    deviceTimebase = $V4;
    boardIndex = $V5;
    portIndex = $V6;
    sub_origin = PRINTF("board %s, port %s", $V5, $V6);
END

CLASS Port_Error_Threshold_Exceeded_CBT
  SELECT
    1: ATTR(=,$ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.52");
    2: $SPECIFIC = 275;
    3: ATTR(=,"portErrorThreshold");
    4: ATTR(=,"portErrorSource");
    5: ATTR(=,"deviceTimebase");
    6: ATTR(=,"boardIndex");
    7: ATTR(=,"portIndex");
  FETCH
    1: IPNAME($AGENT_ADDR);
  MAP
    hostname = $F1;
    portErrorThreshold = $V3;
    portErrorSource = $V4;
    deviceTimebase = $V5;
    boardIndex = $V6;
    portIndex = $V7;
    sub_origin = PRINTF("board %s, port %s", $V6, $V7);
END

CLASS Port_Collision_Threshold_Exceeded_CBT
  SELECT
    1: ATTR(=,$ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.52");
    2: $SPECIFIC = 276;
    3: ATTR(=,"portCollsThreshold");
    4: ATTR(=,"deviceTimebase");
    5: ATTR(=,"boardIndex");
    6: ATTR(=,"portIndex");
  FETCH
    1: IPNAME($AGENT_ADDR);
  MAP
    hostname = $F1;
    portCollsThreshold = $V3;
    deviceTimebase = $V4;
    boardIndex = $V5;
    portIndex = $V6;
    sub_origin = PRINTF("board %s, port %s", $V5, $V6);
END

CLASS Port_Type_Changed_CBT
  SELECT
    1: ATTR(=,$ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.52");
    2: $SPECIFIC = 277;
    3: ATTR(=,"boardIndex");
    4: ATTR(=,"portIndex");
    5: ATTR(=,"portTopologyType");
  FETCH
    1: IPNAME($AGENT_ADDR);
  MAP
    hostname = $F1;
    boardIndex = $V3;
    portIndex = $V4;
    portTopologyType = $V5;
    sub_origin = PRINTF("board %s, port %s", $V3, $V4);
END

CLASS Lock_Status_Changed_CBT
  SELECT
    1: ATTR(=,$ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.52");
    2: $SPECIFIC = 278;
    3: ATTR(=,"deviceSrcAddrLocked");
  MAP
    deviceSrcAddrLocked = $V3;
END

CLASS Port_Security_Violation_CBT
  SELECT
    1: ATTR(=,$ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.52");
    2: $SPECIFIC = 279;
    3: ATTR(=,"boardIndex");
    4: ATTR(=,"portIndex");
    5: ATTR(=,"portSourceAddr");
  FETCH
    1: IPNAME($AGENT_ADDR);
  MAP
    hostname = $F1;
    boardIndex = $V3;
    portIndex = $V4;
    portSourceAddr = $V5;
    sub_origin = PRINTF("board %s, port %s", $V3, $V4);
END

CLASS Port_Violation_Reset_CBT
  SELECT
    1: ATTR(=,$ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.52");
    2: $SPECIFIC = 280;
    3: ATTR(=,"boardIndex");
    4: ATTR(=,"portIndex");
  FETCH
    1: IPNAME($AGENT_ADDR);
  MAP
    hostname = $F1;
    boardIndex = $V3;
    portIndex = $V4;
    sub_origin = PRINTF("board %s, port %s", $V3, $V4);
END

# CLASS Env_Temp_Hot_CBT
# 'envTempHot' traps are mapped to 'envTemperature' OPEN/CRITICAL
CLASS ENV_TEMPERATURE_CBT
SELECT
    1: ATTR(=,$ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.52");
    2: $SPECIFIC = 282;
    3: ATTR(=,"boardIndex");
  FETCH
    1: IPNAME($AGENT_ADDR);
  MAP
    hostname = $F1;
    boardIndex = $V3;
    sub_origin = PRINTF("board %s", $V3);
    severity = CRITICAL;
END

# CLASS Env_Temp_Warm_CBT
# 'envTempWarm' traps are mapped to 'envTemperature' OPEN/WARNING
CLASS Env_Temperature_CBT
  SELECT
    1: ATTR(=,$ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.52");
    2: $SPECIFIC = 281;
    3: ATTR(=,"boardIndex");
  FETCH
    1: IPNAME($AGENT_ADDR);
  MAP
    hostname = $F1;
    boardIndex = $V3;
    sub_origin = PRINTF("board %s", $V3);
    severity = WARNING;
END

# CLASS Env_Temp_Normal_CBT
# 'envTempNormal' traps are mapped to 'envTemperature' CLOSED
CLASS ENV_TEMPERATURE_CBT
  SELECT
    1: ATTR(=,$ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.52");
    2: $SPECIFIC = 284;
    3: ATTR(=,"boardIndex");
  FETCH
    1: IPNAME($AGENT_ADDR);
  MAP
    hostname = $F1;
    boardIndex = $V3;
    sub_origin = PRINTF("board %s", $V3);
    status = CLOSED;
END

#############################################################################
#  Cisco-SPECIFIC SNMP TRAPS
#############################################################################

CLASS Cold_Start_Cisco
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.9");
    2: $TYPE = 0;
    3: ATTR(=,"whyReload");
  FETCH
    1: IPNAME($AGENT_ADDR);
  MAP
    hostname = $F1;
    reason = $V3;
END

CLASS Link_Down_Cisco
  SELECT
    1: ATTR(=,$ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.9");
    2: $TYPE = 2;
    3: ATTR(=,"ifIndex");
    4: ATTR(=,"ifDescr");
    5: ATTR(=,"ifType");
    6: ATTR(=,"locIfReason");
  FETCH
    1: IPNAME($AGENT_ADDR);
  MAP
    hostname = $F1;
    sub_origin = $V4;
    interface_index = $V3;
    interface_description = $V4;
    interface_type = $V5;
    reason = $V6;
END

# For Cisco routers, because we know the interface generating the trap,
# we map 'linkUp' traps to 'linkDown' CLOSED events
CLASS Link_Down_Cisco
  SELECT
    1: ATTR(=,$ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.9");
    2: $TYPE = 3;
    3: ATTR(=,"ifIndex");
    4: ATTR(=,"ifDescr");
    5: ATTR(=,"ifType");
    6: ATTR(=,"locIfReason");
  FETCH
    1: IPNAME($AGENT_ADDR);
  MAP
    hostname = $F1;
    sub_origin = $V4;
    status = CLOSED;
    interface_index = $V3;
    interface_description = $V4;
    interface_type = $V5;
    reason = $V6;
END

CLASS Authentication_Failure_Cisco
  SELECT
    1: ATTR(=,$ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.9");
    2: $TYPE = 4;
    3: ATTR(=,"authAddr");
  FETCH
    1: IPNAME($AGENT_ADDR);
  MAP
    hostname = $F1;
    originating_address = $V3;
END

CLASS EGP_Neighbor_Loss_Cisco
  SELECT
    1: ATTR(=,$ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.9");
    2: $TYPE = 5;
    3: ATTR(=,"egpNeighAddr");
  FETCH
    1: IPNAME($AGENT_ADDR);
  MAP
    hostname = $F1;
    egp_neighbor_address = $V3;
END

CLASS Reload_Cisco
  SELECT
    1: ATTR(=,$ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.9");
    2: $TYPE = 6;
    3: $SPECIFIC = 0;
    4: ATTR(=,"whyReload");
  FETCH
    1: IPNAME($AGENT_ADDR);
  MAP
    hostname = $F1;
    reason = $V3;
END

CLASS TCP_Connection_Close_Cisco
  SELECT
    1: ATTR(=,$ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.9");
    2: $TYPE = 6;
    3: $SPECIFIC = 1;
    4: ATTR(=,"tslineSesType");
    5: ATTR(=,"tcpConnState");
    6: ATTR(=,"loctcpConnElapsed");
    7: ATTR(=,"loctcpConnInBytes");
    8: ATTR(=,"loctcpConnOutBytes");
    9: ATTR(=,"tsLineUser");
  FETCH
    1: IPNAME($AGENT_ADDR);
  MAP
    hostname = $F1;
    tslineSesType = $V4;
    tcpConnState = $V5;
    loctcpConnElapsed = $V6;
    loctcpConnInBytes = $V7;
    loctcpConnOutBytes = $V8;
    tsLineUser = $V9;
END

#############################################################################
#  SNMP-GENERIC TRAPS
#############################################################################

CLASS Cold_Start
  SELECT
    1: $TYPE = 0;
  FETCH
    1: IPNAME($AGENT_ADDR);
  MAP
    hostname = $F1;
END

CLASS Warm_Start
  SELECT
    1: $TYPE = 1;
  FETCH
    1: IPNAME($AGENT_ADDR);
  MAP
    hostname = $F1;
END

CLASS Link_Down
  SELECT
    1: $TYPE = 2;
  FETCH
    1: IPNAME($AGENT_ADDR);
  MAP
    hostname = $F1;
END

CLASS Link_Up
  SELECT
    1: $TYPE = 3;
  FETCH
    1: IPNAME($AGENT_ADDR);
  MAP
    hostname = $F1;
END

CLASS Authentication_Failure
  SELECT
    1: $TYPE = 4;
  FETCH
    1: IPNAME($AGENT_ADDR);
  MAP
    hostname = $F1;
END

CLASS EGP_Neighbor_Loss
  SELECT
    1: $TYPE = 5;
  FETCH
    1: IPNAME($AGENT_ADDR);
  MAP
    hostname = $F1;
END

#
# NetWare Server Alarm Traps
#

#
# The following section defines the mappings for the traps defined in the
# NetWare Server Alarm MIB. Not all Traps have definitions defined. It should
# Be very easy from the examples to extend this mapping. In the event that
# a trap is not specifically matched for the nwalarm-mib object, it is defaulted
# to the NMS_Trap class and the specific trap id is specified.
#
#	ENTERPRISE : nwalarm-mib
#	VARIABLES  : serverName,trapTime, numberOfFailedMemoryAllocAttempts
#
CLASS outOfShortTermMemoryRequestFailed
  SELECT
    1: ATTR(=,$ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 1;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("The system %s failed on one or more short-term memory requests.", $V3);
END
#
#	ENTERPRISE : nwalarm-mib
#	VARIABLES  : serverName,trapTime
#
CLASS errWritingToTheExtendedDirSpace
  SELECT
    1: ATTR(=,$ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 2;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("Error on server %s occurred while writing to hard disk. Data may be corrupted.", $V3);
END
#	ENTERPRISE : nwalarm-mib
#	VARIABLES  : serverName,trapTime,dataStreamNumber
#
CLASS errWritingToFile
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 3;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("An error occurred while writing to file (filename not accessible) data stream on server %s.", $V3);
END
#	ENTERPRISE : nwalarm-mib
#	VARIABLES  : serverName,trapTime,dataStreamNumber,userName,stationNumber
#
CLASS errWritingToFileUsr
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 4;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("An error occurred while writing to file (filename not accessible) data stream by user on server %s", $V3);
END
#	ENTERPRISE : nwalarm-mib
#	VARIABLES  : serverName,trapTime,fileName, dataStreamNumber,volumeName,pathName
#
CLASS errWritingToFileDataStream
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 5;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("Error occurred while writing to file data stream on server %s.", $V3);
END
#	ENTERPRISE : nwalarm-mib
#	VARIABLES  : serverName,trapTime,fileName,dataStreamNumber,userName,stationNumber,
#					volumeName,pathName
#
CLASS errWritingToFileDataStreamUsr
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 6;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("An error occurred while writing to file data stream by user on server %s.", $V3);
END
#	ENTERPRISE : nwalarm-mib
#	VARIABLES  : serverName,trapTime,fileOffset,dataStreamNumber
#
CLASS fileReaderrSrvrNofileName
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 7;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("File read Error. Error getting file name. Request from server %s.", $V3);
END
#	ENTERPRISE : nwalarm-mib
#	VARIABLES  : serverName,trapTime,fileOffset,dataStreamNumber,userName,stationNumber
#
CLASS fileReaderrUsrNofileName
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 8;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("File read Error. Error getting file name. Request from user. on server %s.", $V3);
END
#	ENTERPRISE : nwalarm-mib
#
CLASS fileReaderrDSSrvr
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 9;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("Error reading file data stream. Request from server %s.", $V3);
END
#	ENTERPRISE : nwalarm-mib
#					stationNumber,volumeName,pathName
#
CLASS fileReaderrDSUsr
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 10;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("Error reading file data stream. Request from user on server %s.", $V3);

END
#	ENTERPRISE : nwalarm-mib
#						Read was requested by the server %s."
CLASS fileWritePreReaderrSrvr
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 11;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("File write error in a data stream. Error getting file name. Read was requested by the server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
#						Read was requested by the user on server %s."
CLASS fileWritePreReaderrUsr
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 12;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("File write error in a data stream. Error getting file name. Read was requested by the user on server %s.", $V3);

END

#	ENTERPRISE : nwalarm-mib
#						user on server %s."
CLASS fileWritePreReaderrDSSrvr
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 13;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("File write (pre-read) error in a data stream. Read was requested by user on server %s.", $V3);

END

#	ENTERPRISE : nwalarm-mib
#					stationNumber,volumeName,pathName
#						the user on server %s."
CLASS fileWritePreReaderrDSUsr
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 14;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("File write error in a data stream. Read was requested by the user on server %s.", $V3);

END

#	ENTERPRISE : nwalarm-mib
CLASS cacheMemAllocExceededMinLeftLimit
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 15;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("Cache memory allocator exceeded minimum cache buffer limit on server %s.", $V3);

END

#	ENTERPRISE : nwalarm-mib
CLASS cacheMemAllocOutOfMem
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 16;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    hostname = $V3;
    severity = CRITICAL;
    msg = PRINTF("Cache memory allocator out of available memory on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
#					buffers was less than the system limit."
#
CLASS CacheBuffersGettingLow
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 17;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("The remaning number of cache buffers on server %s is less than the system limit.", $V3);
END

#	ENTERPRISE : nwalarm-mib
#
CLASS volOfDiskSpace
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 18;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "volumeName");
  MAP
    hostname = $V3;
    severity = CRITICAL;
    volumeName = $V5;
    msg = PRINTF("The volume %s on server %s is out of disk space.", $V5, $V3);
END

#	ENTERPRISE : nwalarm-mib
#						by purging files."
#
CLASS volOfDiskSpaceNoPurge
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 19;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "volumeName");
    6: ATTR(=, "diskSpace");
  MAP
    hostname = $V3;
    severity = CRITICAL;
    volumeName = $V5;
    diskSpace = $V6;
    msg = PRINTF("The volume %s on server %s is out of disk space, puging will nbot help.", $V5, $V3);
END

#	ENTERPRISE : nwalarm-mib
#					Low Warning Threshold value."
#
CLASS volAlmostOutOfDiskSpace
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 20;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "volumeName");
  MAP
    hostname = $V3;
    severity = WARNING;
    volumeName = $V5;
    msg = PRINTF("The volume %s on server %s is almost out of disk space.", $V5, $V3);
END

#	ENTERPRISE : nwalarm-mib
#					volume on server %s."
CLASS errWritingFatTables
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 21;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "volumeName");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    volumeName  = $V5;
    msg = PRINTF("An error has occurred while writing the FAT tables for a particular volume on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
#
CLASS errWritingDirectoryBlk
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 22;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "volumeName");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    volumeName = $V5;
    severity = WARNING;
    msg = PRINTF("An error has occurred while writing a directory block on a particular volume on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
#
CLASS dirCopyReadErr
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 23;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "volumeName");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    volumeName = $V5;
    severity = WARNING;
    msg = PRINTF("An error has occurred while reading one copy of a directory on a particular volume on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
#
CLASS errReadingBothCopiesofDir
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 24;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "volumeName");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    volumeName = $V5;
    severity = WARNING;
    msg = PRINTF("An error has occurred while reading both copies of directory from a particular volume on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS allocateDirEntryWriteError
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 25;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "volumeName");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    volumeName = $V5;
    severity = WARNING;
    msg = PRINTF("A disk error occurred  on server %s while writing a newly allocated block on a volume. HotFix could not correct it.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS errExpandingDirDuetoWriteErr
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 26;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "volumeName");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    volumeName = $V5;
    severity = WARNING;
    msg = PRINTF("A disk error occurred on a volume while expanding an existing directory. HotFix could not correct it on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS dirReachedItsLimit
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 27;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "volumeName");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    volumeName = $V5;
    severity = WARNING;
    msg = PRINTF("A disk error occurred  on server %s on a volume while expanding an existing directory because the directory size reached its limit.", $V3);
END

#	ENTERPRISE : nwalarm-mib
# "A disk error occurred  on server %s on a volume while expanding an existing directory because no more disk space was available."
CLASS errExpandingNoDiskSpace
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 28;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "volumeName");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    volumeName = $V5;
    severity = WARNING;
    msg = PRINTF("A disk error occurred  on server %s on a volume while expanding an existing directory because no more disk space was available.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS errExpandingNoMemSpace
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 29;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "volumeName");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    volumeName = $V5;
    severity = WARNING;
    msg = PRINTF("A disk error occurred  on server %s on a volume while expanding an existing directory because no more server memory was available to expand directory tables.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS dirSizeGettingTooLrgeForMem
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 30;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "volumeName");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    volumeName = $V5;
    severity = WARNING;
    msg = PRINTF("The volume directory table is getting too large for server memory on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS lanReceiveBuffLimitReached
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 31;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("No OS LAN buffers are available for receiving packets on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS connTerminatedByWatchDog
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 32;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("Watchdog cleared the user connection on server %s", $V3);
END

#	ENTERPRISE : nwalarm-mib
#	VARIABLES  : serverName,trapTime,processName,nlmName,codeOffset,memoryAddress
CLASS writeFault
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 34;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("An NLM tried to write to a memory location where it did not have write rights on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
#	VARIABLES  : serverName,trapTime,processName,nlmName,codeOffset,memoryAddress
CLASS readFault
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 35;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("An NLM tried to read a memory location where it did not have read rights on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS ipxReceivedIncomPacket
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 36;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("IPX is receiving incomplete packets from a node on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS unableToCreateVOL
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 37;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "volumeName");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    volumeName = $V5;
    severity = WARNING;
    msg = PRINTF("The system error log file (VOLLOG.ERR) could not be created on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS unableToWriteVOLERR
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 38;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "volumeName");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    volumeName = $V5;
    severity = WARNING;
    msg = PRINTF("The system error log file (VOLLOG.ERR) could not be written to on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS volStillOprDespiteDeviceDriveDeact
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 39;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "volumeName");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    volumeName = $V5;
    severity = WARNING;
    msg = PRINTF("The volume is still accessible although it is no longer fully mirrored on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS loginDisabled
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 40;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "userName");
    6: ATTR(=, "stationNumber");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    userName = $V5;
    stationNumber = $V6;
    msg = PRINTF("A specified user issued a disable login command on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS loginEnabled
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 41;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "userName");
    6: ATTR(=, "stationNumber");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    userName = $V5;
    stationNumber = $V6;
    severity = WARNING;
    msg = PRINTF("A specified user issued an enable login command on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS clrStnByConsole
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 42;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("A specified connection was cleared at the server console on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS clrStnByUsr
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 43;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("A specified connection was cleared from a workstation on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS fileserverdowned
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 44;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("The file server %s was downed from a workstation console.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS errOpeningRIPSocket
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 45;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("The server %s encountered an error while opening a RIP socket.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS rtrConfigErr
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 46;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = "A router claims that a particular network address should actually be another address.";
END

#	ENTERPRISE : nwalarm-mib
CLASS lanDriverLoopBack
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 47;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = "A particular LAN driver received its own packet.";
END

#	ENTERPRISE : nwalarm-mib
CLASS dupInternetAddr
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 48;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = "Two routers are claiming the same internet address.";
END

#	ENTERPRISE : nwalarm-mib
CLASS lanBdUnreachable
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 49;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = "An IPX local network was removed because the LAN board was unreachable.";
END

#	ENTERPRISE : nwalarm-mib
CLASS ipxUnbndRequest
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 50;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = "An IPX local network was removed because of an UNBIND request.";
END

#	ENTERPRISE : nwalarm-mib
CLASS errOpeningSAPSocket
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 51;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("The server %s encountered an error while opening a SAP socket.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS rtrClaimingSameInterAddr
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 52;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = "Two routers are claiming the same internet address.";
END

#	ENTERPRISE : nwalarm-mib
#	VARIABLES  : serverName,trapTime,interruptNumber
CLASS spuriousInt
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 53;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = "No interrupt service routine was registered with this driver.";
END

#	ENTERPRISE : nwalarm-mib
CLASS checksumInvalid
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 54;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("An IPX NCP packet with invalid checksum was received on server %s. Possible network corruption.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS prmyPicLostInterrupt
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 55;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("The hardware set an interrupt but when the CPU responded to it the interrupt was no longer available on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS scndryPicLostInterrupt
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 56;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("The hardware set an interrupt but when the CPU responded to it the interrupt was no longer available on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS NMSexception
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 57;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "domainName");
    6: ATTR(=, "processName");
    7: ATTR(=, "nlmName");
    8: ATTR(=, "codeOffset");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    domainName = $V5;
    processName = $V6;
    nlmName = $V7;
    codeOffset = $V8;
    severity = WARNING;
    msg = PRINTF("An exception occurred due to an NLM writing to an invalid memory address on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS invalidScreenID
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 58;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("An NLM passed an invalid screen ID to the kernel on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS prssDidNotRelqhCntlFqtly
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 59;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("An NLM did not relinquish control within the system execution limit of .4 seconds on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS fileSrvrUsrDeleted
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 60;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "userName");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    userName = $V5;
    severity = WARNING;
    msg = PRINTF("A user account was deleted while the user was logged in on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS usrAcctDeletedByAUsr
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 61;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("A user account was deleted by another user on server %s. The deleted user was logged in at the time.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS invalidResourceTag
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 62;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("An invalid resource tag was passed to the OS on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS diskDeactivatedUnknownReason
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 63;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "deviceName");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    deviceName = $V5;
    severity = WARNING;
    msg = PRINTF("A disk has been deactivated on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS diskDeactivatedDriverUnload
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 64;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "deviceName");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    deviceName = $V5;
    severity = WARNING;
    msg = PRINTF("The system deactivated the specified disk because the associated driver was unloaded by a console operator command on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS diskDeactivatedDeviceFailure
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 65;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "deviceName");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    deviceName = $V5;
    severity = WARNING;
    msg = PRINTF("A disk has been deactivated by the disk driver due to device failure on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS diskDeactivatedUsrRequest
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 66;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "deviceName");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    deviceName = $V5;
    severity = WARNING;
    msg = PRINTF("The system deactivated the specified disk because the associated driver was unloaded by a user-initiated UNLOAD command on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS diskDeactivatedMediaDismount
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 67;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "deviceName");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    deviceName = $V5;
    severity = WARNING;
    msg = PRINTF("The OS  on server %s detected that a different medium was loaded in a drive and deactivated the disk.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS diskDeactivatedEOM
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 68;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "deviceName");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    deviceName = $V5;
    severity = WARNING;
    msg = PRINTF("The system %s deactivated the specified disk because the end of the medium was reached.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS diskDeactivatedSrvrDown
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 69;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "deviceName");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    deviceName = $V5;
    severity = WARNING;
    msg = PRINTF("The system %s deactivated the specified disk because the associated driver was unloaded by a user-initiated DOWN server command.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS diskDeactivatedServerFailure
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 70;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "deviceName");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    deviceName = $V5;
    severity = WARNING;
    msg = PRINTF("The specified disk has been deactivated because the OS  on server %s detected a failure in the file system.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS moduleDidNotReleaseOneResource
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 71;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("An NLM did not release a resource on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS mirroredPartNotAllSyncPart
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 72;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "partitionNumber");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    partitionNumber = $V5;
    severity = WARNING;
    msg = PRINTF("The system %s has not mirrored all system partitions that are designated as mirrored partitions.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS allMirroredPartAreSync
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 73;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("The system %s has mirrored all system partitions that are designated as mirrored partitions.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS partitionsSync
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 74;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "partitionNumber");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    partitionNumber = $V5;
    severity = WARNING;
    msg = PRINTF("This mirrored partition is synchronized on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS partitionsUnSync
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 75;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "partitionNumber");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    partitionNumber = $V5;
    severity = WARNING;
    msg = PRINTF("This logical partition is not synchronized on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS remirroringPart
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 76;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "partitionNumber");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    partitionNumber = $V5;
    severity = WARNING;
    msg = PRINTF("The system %s is remirroring this partition.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS abortRemirrorPart
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 77;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "partitionNumber");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    partitionNumber = $V5;
    severity = WARNING;
    msg = PRINTF("The system %s tried to remirror a partition to another partition and failed.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS mirrorInconsistencies
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 78;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "partitionNumber");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    partitionNumber = $V5;
    severity = WARNING;
    msg = PRINTF("This logical partition has certain inconsistencies on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS systemFileLockThresholdReached
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 79;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("System File lock threshold reached on server %s. New locks will fail.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS stationFileLockThresholdReached
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 80;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("Station file lock threshold reached on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS systemRecordLockThresholdReached
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 81;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("System record lock threshold reached on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS stationRecordLockThresholdReached
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 82;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("Station record lock threshold reached on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS errorOpeningNetAcctData
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 83;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("Cannot open file NET$ACCT.DAT to add audit record on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS ncpSearchLimitExecBySrvr
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 84;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = "A server requested an NCP directory search, and the limit for outstanding search was already reached.";
END

#	ENTERPRISE : nwalarm-mib
CLASS ncpSearchLimitExecByStation
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 85;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = "A user requested an NCP directory search, and the limit for outstanding search was already reached.";
END

#	ENTERPRISE : nwalarm-mib
CLASS insertMediaAck
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 86;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("The insertion of a medium into a drive is acknowledged on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS insertMediaAborted
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 87;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("A previously requested insert media request is negated on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS ramMediaAck
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 88;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("The removal of a medium from a device is acknowledged on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS ramMediaAborted
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 89;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("Previously issued remove media request aborted on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS insertDSMediaInto
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 90;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("The media manager requires the double-sided medium to be inserted into the device on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS removeMediaFrom
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 91;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("Media needs to be removed from device on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS redirectBlk
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 92;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("HotFix was able to redirect a block on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS couldNotRedirectBlk
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 93;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("HotFix was unable to redirect a block on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS outOfHotFixBlks
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 94;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("The redirection area set aside on a partition is exhausted on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS fewRedirectionBlks
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 95;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("There are only few disk blocks available for redirection on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS redirectInconsistNoFix
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 96;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "partitionNumber");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    partitionNumber = $V5;
    severity = WARNING;
    msg = PRINTF("The inconsistencies in the redirection tables found in the hotfix area could not be fixed by the media manager on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS redirectInconsistFix
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 97;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "partitionNumber");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    partitionNumber = $V5;
    severity = WARNING;
    msg = PRINTF("The inconsistencies in the redirection tables found in the hotfix area were fixed by the media manager on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS invalidResourceTagPassed
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 98;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("A loaded NLM tried to register hardware options with an invalid resource tag on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS checkAddHardware
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 99;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("The NetWare OS tried to allocate memory for a system API and failed on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS removeHardwareOptions
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 100;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("An executing NLM called the OS function RemoveHardwareOptions with an invalid pointer on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS errUnloadKilledNlm
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 101;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("An NLM being unloaded has exported variables that are in use by other NLMs on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS invldRrceTagPsedToCreatePrss
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 102;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("The system tried to start a new NLM or create a process for an active NLM, but the NLM did not allocate a resource tag or used an invalid resource tag on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS createPrssReqdStackTooSmall
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 103;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("The system tried to load an NLM that allocated insufficient stack for itself on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS createPrssUnableToAllctePrssCntlBlk
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 104;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("The system tried to start a new NLM but there was not enough memory on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS filePreservationErrorDuringErase
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 105;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "volumeName");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    volumeName = $V5;
    severity = WARNING;
    msg = PRINTF("An error prevented the preservation of a file during file deletion on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS filePreservationErrorInsuffSpace
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 106;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "volumeName");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    volumeName = $V5;
    severity = WARNING;
    msg = PRINTF("Insufficient directory table space or memory available during file deletion on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS mlidResetLanBd
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 107;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = "A bind command issued to an IPX LAN driver with a wrong network number caused the MLID to reset the LAN board.";
END

#	ENTERPRISE : nwalarm-mib
CLASS reqtdRtrReset
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 108;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("A workstation issued a router reset command to the server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS volContainstheWrongDOSType
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 109;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "volumeName");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    volumeName = $V5;
    severity = WARNING;
    msg = PRINTF("The volume has a DOS TYPE different from that for which the server %s was configured.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS originalNameSpaceNotFound
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 110;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("Function GetOriginalNameSpace could not find a name space on server %s. DOS name space was assumed.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS readTimeDataMigratorDefaultSupportModuleChanged
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 111;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("A real-time data migrator default support module was changed by the application on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS errCreateOpenTTSLogFile
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 112;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("The server %s could not open or create the TTS$LOG file." , $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS errWriteOpenTTSLogFile
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 113;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("The server %s could not write to a TTS$LOG file.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS ttsDownbyVolDismount
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 114;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "volumeName");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    volumeName = $V5;
    severity = WARNING;
    msg = PRINTF("Since the SYS volume was dismounted TTS is no longer available on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS disableTTSbyUser
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 115;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = "A disable TTS command was issued from a workstation.";
END

#	ENTERPRISE : nwalarm-mib
CLASS ttsDisabledByOperator
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 116;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("TTS disabled by operator on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS ttsDisErrReadTTSduringBackout
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 117;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("TTS disabled due to error reading backout file on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS ttsDisErrWritingTTSduringBackout
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 118;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("TTS was disabled because there was an error writing to a file during transaction backout on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS ttsDisErrTooManyDefInfo
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 119;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("TTS was disabled because of too many defined volumes on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS ttsDisErrWritingVolDefInfo
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 120;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("TTS was disabled due to an error writing volume definition information on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS ttsDisErrRdBlkFlRecGen
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 121;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("TTS was disabled due to error reading backout file during record generation on server %s", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS ttsDisGrowMemTables
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 122;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("TTS was disabled because TTS tables were getting too big on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS ttsDisErrAllDiskSpace
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 123;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("TTS was disabled because of an error allocating more disk space during backout on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS ttsDisDirErrOnBkFile
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 124;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("TTS was disabled because of a directory error on TTS backout file on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS enableTTSByUser
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 125;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = "TTS was enabled from a workstation.";
END

#
#
#	ENTERPRISE : nwalarm-mib
CLASS transactionAbortedForStation
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 126;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = "A transaction was not backed out due to a clear station command.";
END

#	ENTERPRISE : nwalarm-mib
CLASS ttsLimitExceeded
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 127;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("TTS has exceeded the maximum number of transactions on serve %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS ttsNoMemForExpandingTxNodeTables
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 128;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = "TTS ran out of memory expanding transaction node tables.";
END

#	ENTERPRISE : nwalarm-mib
CLASS auditEvent
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 129;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("An audit request was made with an invalid volume number on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS auditAlertThresholdOverFlow
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 130;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "volumeName");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    volumeName = $V5;
    severity = WARNING;
    msg = PRINTF("There was an audit threshold overflow on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS auditAlertInvalidConfigurationFile
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 131;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "volumeName");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    volumeName = $V5;
    severity = WARNING;
    msg = "Auditing disabled file.";
END

#	ENTERPRISE : nwalarm-mib
CLASS auditAlertNoMemory
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 132;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "volumeName");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    volumeName = $V5;
    severity = WARNING;
    msg = PRINTF("Memory for auditing cannot be allocated on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS auditFileWriteError
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 133;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "volumeName");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    volumeName = $V5;
    severity = WARNING;
    msg = PRINTF("Audit-file write error on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS auditFileFull
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 134;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "volumeName");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    volumeName = $V5;
    severity = WARNING;
    msg = PRINTF("Audit file full on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS invalidConnTypetoAllocConn
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 135;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = "An executing NLM tried to allocate a connection number but an invalid connection type was passed as a parameter.";
END

#	ENTERPRISE : nwalarm-mib
CLASS invalidRsrcTagPassedtoAllocConn
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 136;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = "An executing NLM tried to allocate a connection number but an invalid resource tag was passed as a parameter.";
END

#	ENTERPRISE : nwalarm-mib
CLASS outOfServerConn
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 137;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = "A request to allocate a connection number for a workstation could not be granted because the maximum number of connections had been allocated.";
END

#	ENTERPRISE : nwalarm-mib
CLASS connTerminated5MinNotice
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 138;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("Server watchdog logged out the connection since the user did not log in for five minutes on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
#				 The user whose account was disabled was logged in at the time."
CLASS usrAcctDisabledByAUsr
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 139;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = "A user account was disabled by another user. The user whose account was disabled was logged in at the time.";
END

#	ENTERPRISE : nwalarm-mib
CLASS useOfUnEncryptedPwd
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 140;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("An application or utility tried to log in or change a password using an unencrypted password on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS supAcctLockoutClrdByConsole
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 141;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("An account locked by a supervisor is now cleared on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS systemTimeChangedByConsole
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 142;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("The system time was changed from the server %s console.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS systemTimeChangedByUser
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 143;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("The system time  on server %s was changed from a user console.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS volDismountedDueToDeviceDriveDeact
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 144;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "volumeName");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    volumeName = $V5;
    severity = WARNING;
    msg = "The volume is still dismounted due to driver unload, disk failure, or OS-initiated driver unload.";
END

#	ENTERPRISE : nwalarm-mib
#					internalNetworkAddress1,macAddress1,macAddress2
CLASS rtrFalsehood
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 145;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = "A router is falsely claiming that a particular network address has been changed to a different address.";
END

#	ENTERPRISE : nwalarm-mib
#					networkAddress1,macAddress1,socketNumber1,macAddress2
CLASS srvAddrChanged
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 146;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = "A particular server address has been changed.";
END

#	ENTERPRISE : nwalarm-mib
CLASS extendFileHasNoOwnerToCharge
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 147;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("A file occupying a certain percentage of disk space has no owner to charge on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS rtrConfigErr3
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 148;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = "A router claims that a particular network address should actually be another address.";
END

#	ENTERPRISE : nwalarm-mib
CLASS rtrConfigErr2
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 149;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = "A router claims that a particular network address should actually be another address.";
END

#	ENTERPRISE : nwalarm-mib
CLASS dmNotLoadedWhenRequested
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 150;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "volumeName");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    volumeName = $V5;
    severity = WARNING;
    msg = PRINTF("A read/write request was made to the real-time data migration module, but the module was not loaded on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS noSpecificSupportModulesLoaded
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 151;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "volumeName");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    volumeName = $V5;
    severity = WARNING;
    msg = PRINTF("A read/write request was made to the real-time data migration module, but the required data migration support module was not loaded on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS notEnoughRAMForComp
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 152;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("Insufficient RAM to compress file on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS diskErrorCompression
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 153;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("Disk I/O error compressing file on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
#					fileMiscInfo1
CLASS compressErrorHoleCountMismatch
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 154;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = "There was an internal compression error on the sparse count found on the linked list maintained by the compression executables.";
END

#	ENTERPRISE : nwalarm-mib
CLASS unknownErrorCompression
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 155;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("There was an unknown error during file compression on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS insufficientSpaceForDecompression
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 156;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("Insufficient disk space to decompress file on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS decompUnknownCompVersion
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 157;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("File being decompressed has unknown compression format on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS unknownErrorDecomp
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 158;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("Unknown error returned from file decompress on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS insufficientDecompError
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 159;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("Insufficient RAM to decompress file on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS compFileCorrupted
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 160;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("Compressed file is corrupt and unrecoverable on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS rejectedIncompleteNCP
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 161;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("The server %s received an incomplete NCP packet from a workstation and rejected the packet.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS stationUsedABadPacket
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 162;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("The server %s received an incomplete NCP packet from a workstation and processed it.", $V3);
END

#	ENTERPRISE : nwalarm-mib
# "A server received an NCP with the length field improperly initialized and rejected it."
CLASS rejectedNCPBadSubfunctionLngth
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 163;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("The server %s received an NCP with the length field improperly initialized and rejected it.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS processedNCPBadSubfunctionLngth
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 164;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("The server %s received an NCP with the length field improperly initialized and processed it.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS compFilePathCorrupted
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 165;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("Compressed file with path is corrupted and unrecoverable on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS compFileInUse
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 166;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("Compressed file in use is corrupt and unrecoverable on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS nlmNoPriorty
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 167;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("A loaded NLM is not allowing other low-priority threads to run on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS workToDo
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 168;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("A Work-to-do thread took more than a minute of CPU time on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS compErrTempFileErr
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 169;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("There was an invalid byte in the temporary file created during file compression on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
#					fileMiscInfo1

#	ENTERPRISE : nwalarm-mib
CLASS compErrReadZeroBytesInt
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 175;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("The disk has returned 0 bytes for a compression read request and there is still more data to read on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib

#	ENTERPRISE : nwalarm-mib
CLASS signatureInvalid
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 178;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("NCP packet with invalid signature was received by server %s. Possible packet forgery.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS licenseInvalid
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 179;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("The license is invalid on server %s. Maximum connections reduced to one.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS deactHotFix
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 180;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("There was a media failure and hotfix could not fix it. The device was deactivated on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS unknownDecompressErrorWithName
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 181;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("A unknown error was returned from file decompression on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS insufficientRamToDecompressWithName
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 182;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("Insufficient RAM to decompress file on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS decompressUnderFreePercentage
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 183;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "volumeName");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    volumeName = $V5;
    severity = WARNING;
    msg = PRINTF("Compressed files are not being committed as decompressed due to lack of disk space on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS negPktLargeBuffer
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 184;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = "An NCP negotiation packet tried to negotiate a connection request packet that was larger than the driver could handle. The request was rejected by IPX.";
END

#	ENTERPRISE : nwalarm-mib
CLASS loginDisabledByConsole
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 185;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("A disable login command was issued at the server console on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS loginEnabledByConsole
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 186;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("An enable login command was issued at the server console on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS growableStackNotAllocated
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 187;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("A loaded NLM tried to create a stack and failed on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS insertDSMediaAck
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 188;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "deviceName");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    deviceName = $V5;
    severity = WARNING;
    msg = PRINTF("The insertion of a double-sided medium into a drive is acknowledged on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS insertMagazineAck
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 189;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "deviceName");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    deviceName = $V5;
    severity = WARNING;
    msg = PRINTF("The insertion of a magazine into a drive is acknowledged on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS insertDSMediaAborted
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 190;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "deviceName");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    deviceName = $V5;
    severity = WARNING;
    msg = PRINTF("Previously requested insert double-sided media request is withdrawn on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS insertMagazineAborted
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 191;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "deviceName");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    deviceName = $V5;
    severity = WARNING;
    msg = PRINTF("Previously requested insert magazine request is withdrawn on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS ramDSMediaAck
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 192;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "deviceName");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    deviceName = $V5;
    severity = WARNING;
    msg = PRINTF("Removal of a double-sided medium from a device is acknowledged on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS ramMagazineAck
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 193;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "deviceName");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    deviceName = $V5;
    severity = WARNING;
    msg = PRINTF("Removal of a magazine from a device is acknowledged on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS ramDSMediaAborted
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 194;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "deviceName");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    deviceName = $V5;
    severity = WARNING;
    msg = PRINTF("Previously requested remove double-sided media request aborted on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS ramMagazineAborted
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 195;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "deviceName");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    deviceName = $V5;
    severity = WARNING;
    msg = PRINTF("Previously requested remove magazine request aborted on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS insertMagazineInto
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 196;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("The media manager requires a magazine to be inserted into the device on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS removeDSMediaFrom
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 197;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "deviceName");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    deviceName = $V5;
    severity = WARNING;
    msg = PRINTF("The media manager requires a double-sided medium to be removed from a device on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS removeMagazineFrom
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 198;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "deviceName");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    deviceName = $V5;
    severity = WARNING;
    msg = PRINTF("The media manager requires a magazine to be removed from a device on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS moduleDidNotReleaseResources
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 199;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("An NLM did not release resources on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS opnBinderyFailSinceVolNotMounted
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 200;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("Server %s failed to open the bindery. Request failed because the SYS volume was not mounted.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS binderyOpnReqtdByUsrFailed
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 201;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = "A user tried to open the bindery and failed since the SYS volume was not mounted.";
END

#	ENTERPRISE : nwalarm-mib
CLASS binderyOpnReqtdBySrvr
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 202;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("The server %s has opened the bindery.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS binderyOpnReqtdByUsr
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 203;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("The user tried to open the bindery on server %s and succeeded.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS binderyClosedBySrvr
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 204;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("The server %s has closed the bindery.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS binderyClosedByUsr
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 205;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = "The user has requested a bindery to be closed.";
END

#	ENTERPRISE : nwalarm-mib
CLASS intruderLockout
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 206;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = "User account temporarily disabled due to repeated login attempt with wrong password.";
END

#	ENTERPRISE : nwalarm-mib
CLASS dsOpenFailed
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 207;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("Directory services database did not open on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS dsOpenFailedInconsistentDatabase
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 208;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("Directory services database did not open due to inconsistent database on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS dsopenSucceeded
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 209;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("The directory services database was successfully opened on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS dsCloseSucceeded
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 210;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("The directory services database was successfully closed on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS skulkingError
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 211;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "errorNumber");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    errorNumber = $V5;
    severity = WARNING;
    msg = PRINTF("Skulking error on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS dsIntruderNoAddr
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 212;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = "A user repeatedly tried to log in with an invalid password and the user's account was temporarily disabled by the supervisor." ;
END

#	ENTERPRISE : nwalarm-mib
CLASS domainQuarantined
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 213;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = "There was a protection violation in one of the NLMs in the OSP domain during execution. The NLM is quarantined.";
END

#	ENTERPRISE : nwalarm-mib
CLASS commandProcess
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 214;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("The command processor faulted while loading an NLM on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS remoteConnGranted
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 215;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("A request to use a workstation console as a file server console was granted on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS remoteConnCleared
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 216;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("A request to clear the use of a workstation console as a file server console was granted on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS remoteConnRefused
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 217;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("A request to use the workstation console as a file server console was refused on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS translatorUp
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 218;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("The Trap NLM is loaded on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS translatorDown
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 219;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("The Trap NLM is being unloaded on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS volAnyMounted
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 220;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "volumeName");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    volumeName = $V5;
    severity = WARNING;
    msg = PRINTF("The server %s mounted the indicated volume in response to a MOUNT command.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS volAnyDismounted
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 221;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "volumeName");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    volumeName = $V5;
    severity = WARNING;
    msg = PRINTF("The server %s dismounted the indicated volume in response to a DISMOUNT command.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS serverDownatServer
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 222;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("The server %s was downed at the server console.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS protocolBound
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 223;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = "A protocol stack has been bound to a LAN driver.";
END

#	ENTERPRISE : nwalarm-mib
CLASS protocolUnBound
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 224;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = "A protocol stack has been unbound from a LAN driver.";
END

#	ENTERPRISE : nwalarm-mib
CLASS moduleLoad
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 225;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "nlmName");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    nlmName = $V5;
    severity = WARNING;
    msg = PRINTF("An NLM has been loaded on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS moduleUnLoad
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 226;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "nlmName");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    nlmName = $V5;
    severity = WARNING;
    msg = PRINTF("An NLM has been unloaded on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS mlidRegister
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 227;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("MLID has registered a board on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS mlidUnRegister
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 228;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("MLID has de-registered a board on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS clearConnection
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 229;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("A user connection has been cleared on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS loginConnection
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 230;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "userName");
    6: ATTR(=, "connectionNumber");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    userName = $V5;
    connectionNumber = $V6;
    severity = WARNING;
    msg = PRINTF("A user has logged in on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS genericAlert
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 231;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = "This trap will handle all traps being generated by third-party NLMs and the traps generated by driver NLMs written by NOVELL or third party.";
END

#	ENTERPRISE : nwalarm-mib
# "A user has logged out."
CLASS logoutConnection
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 232;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "userName");
    6: ATTR(=, "connectionNumber");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    userName = $V5;
    connectionNumber = $V6;
    severity = WARNING;
    msg = PRINTF("A user has logged out on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS usrAcctDeletedByAUsrSingleConn
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 233;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = "A user account was deleted by another user. The deleted user was logged in at the time. ";
END

#	ENTERPRISE : nwalarm-mib
CLASS compErrReadZeroBytesOrig
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 234;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("The disk has returned 0 bytes for a compression read request and there is still more data to read on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
# Any of the following is a possible cause:
#				a: deactivated by a console command.
#				b: disk drive failure.
#				c: driver unload.
#				d: file system failure.
#				e: wrong medium.
#				f: end-of-medium.
#				g: end-of-medium warning.
#				h: unload command.
#				i: dismount command.
#				j: down command.   "
#
CLASS diskDeactivated
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 235;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("The specified disk was deactivated on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS diskMounted
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 236;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "diskName");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    diskName = $V5;
    severity = WARNING;
    msg = PRINTF("The system %s mounted the specified removable disk at the user's request.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS redirectBlockMismatch
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 237;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("The system %s detected a redirection block mismatch.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS shortTermMemoryLimitExceeded
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 238;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("Short-term memory requests are failing on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS semipermanentMemoryExhausted
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 239;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("Semi-permanent memory exhausted on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS diskDismounted
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 240;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "diskName");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    diskName = $V5;
    severity = WARNING;
    msg = PRINTF("The system %s mounted the specified removable disk at the user's request.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS diskAdded
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 241;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = "The specified hard disk has been added to the operating system";
END

#	ENTERPRISE : nwalarm-mib
CLASS diskActivated
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 242;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = "The specified hard disk has been activated at the user's request.";
END

#	ENTERPRISE : nwalarm-mib
#				 due to one of the
#				following reasons:
#				- disabled by operator,
#				- error reading TTS file during backout,
#				- error writing to file during backout,
#				- too many defined volumes,
#				- error writing volume information to TTS file,
#				- error reading TTS file during record
#				generation,
#				- error growing TTS tables,
#				- error allocating new space for the TTS
#				backout file,
#				- error writing directory information for the
#				 TTS backout file.
# "
CLASS generalTTSfailures
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 243;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("TTS was disabled", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS mirroredPartNotAllSync
  SELECT 1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
	 2: $SPECIFIC = 244;
	 3: ATTR(=, "serverName");
	 4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("The system %s has not mirrored all system partitions that are designated as mirrored partitions.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS reqtdRtrReset311
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 245;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("A workstation issued a router reset command to the server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS invalidSignatureString
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 246;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("The system %s detected an NCP packet with invalid signature.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS invalidDuplicateSignature
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 247;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("The system %s detected a duplicate NCP packet that was different from the original packet.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS invalidPburstSignature
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 248;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("The system %s received an NCP packet burst request with an invalid security signature.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS failedToDeleteMigrateFile
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 249;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
    5: ATTR(=, "volumeName");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    volumeName = $V5;
    severity = WARNING;
    msg = PRINTF("The system %s tried to delete a migrated file but failed because it was unable to obtain directory table space or memory.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS unsignedRemoteConnectionRefused
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 250;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = "A request to use the workstation console as a file server console was refused. The packet did not have a signature.";
END

#	ENTERPRISE : nwalarm-mib
CLASS unsignedRemoteConnectionGranted
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 251;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = "A request to use the workstation console as a file server console was granted.";
END

#	ENTERPRISE : nwalarm-mib
CLASS responsePacketNotAllocated
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 252;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = "More responses were present from workstations than there were buffers to hold them.";
END

#	ENTERPRISE : nwalarm-mib
CLASS wsNotLocated
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 253;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = "A response was received from a remote workstation, but it did not apply to this connection.";
END

#	ENTERPRISE : nwalarm-mib
CLASS remoteConnectionTimedOut
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 254;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("The system watchdog timed out the remote connection on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS modemConnectionCleared
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 255;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("Since the remote partner was gone, the modem connection was cleared. ", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS remoteConnectionClearedNameKnown
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 256;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("The remote connection permission granted earlier has been cleared on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS callBackNumberNotReceived
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 257;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = "A workstation tried to connect to a server through a modem but failed. ";
END

#	ENTERPRISE : nwalarm-mib
CLASS nlmUnableToOpenListFile
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 258;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("The call-back option has been enabled, but the call-back list file, SYS:SYSTEM\CALLBACK.LST, could not be opened on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS nlmUnableToReadListFile
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 259;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("The call-back option has been enabled, but the call-back list file, SYS:SYSTEM\CALLBACK.LST, could not be read on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS unauthorizedCallBackNumber
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 260;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = "The call-back option has been enabled, but the call-back list file, SYS:SYSTEM\CALLBACK.LST, does not contain the number that was sent from the remote workstation.";
END

#	ENTERPRISE : nwalarm-mib
CLASS modemClearedAndCallBackAttempted
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 261;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("The connection with modem has been cleared. The server %s will now attempt to call back the number.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS attemptingToEstablishCallBackConnection
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 262;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("The server %s is trying to call-back the number given to it during the modem connection process.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS remoteConnectionRefusedNameKnown
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 263;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = "Request for a remote connection was refused.";
END

#	ENTERPRISE : nwalarm-mib
CLASS remoteConnectionGrantedNameKnown
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 264;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = "Request for a remote connection was granted.";
END

#	ENTERPRISE : nwalarm-mib
CLASS modemConnectionEstablished
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 265;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = "The modem connection has been established at a particular baud rate.";
END

#	ENTERPRISE : nwalarm-mib
CLASS dsAuditFileWriteError
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 266;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("The operating system encountered an error when attempting to write to the audit file on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS dsAuditFileFull
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 267;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("The operating system filled up the audit file when it wrote an audit record on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS dsAuditFileThresholdOverflow
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 268;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("The operating system encountered a warning threshold level for the volume when writing an audit record on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS dsAuditMemoryAllocation
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 269;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("The operating system ran out of memory when it started up auditing while mounting a volume on server %s.", $V3);
END

#	ENTERPRISE : nwalarm-mib
CLASS serverUp
  SELECT
    1: ATTR(=,$ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.23.2.10");
    2: $SPECIFIC = 270;
    3: ATTR(=, "serverName");
    4: ATTR(=, "trapTime");
  MAP
    specificTrap = $V2;
    hostname = $V3;
    severity = WARNING;
    msg = PRINTF("NetWare Server %s is up.", $V3);
END
